<?php

namespace EMS\PortalFuncionario\Geral\Controllers;

use EMS\PortalFuncionario\Geral\Services\AvaliacaoService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use EMS\Util\ExpectedException;

class AvaliacaoController {
    /** @var AvaliacaoService */
    protected $avaliacaoService;

    public function __construct(
        AvaliacaoService $avaliacaoService
    ) {
        $this->avaliacaoService = $avaliacaoService;
    }

    public function getAvaliacoes(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $nrOrg     = (int) $row['NRORG'];
            $cdOperador = (string) $row['CDOPERADOR'];

            $avaliacoes = $this->avaliacaoService->getAvaliacoes(
                $nrOrg, $cdOperador
            );

            $response->addDataSet(new DataSet('data', $avaliacoes));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function getQuestoesAvaliacao(
        Request\Filter $request,
        Response $response
    ) {
        try {
            $row = $request->getParameters();

            $questoes = $this->avaliacaoService->getQuestoesAvaliacao(
                $row
            );

            $response->addDataSet(new DataSet('data', $questoes));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }

    public function salvarAvaliacao(
        Request\Row $request,
        Response $response
    ) {
        try {
            $row = $request->getRow()->getArrayCopy();

            $success = $this->avaliacaoService->salvarAvaliacao(
                $row
            );

            $dataSet = [
                'success' => $success,
            ];

            $response->addDataSet(new DataSet('data', $dataSet));
        } catch (ExpectedException $e) {
            $response->addMessage(new Message($e->getMessage(), Message::TYPE_ERROR));
        }  catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTrace()));
        }
    }
}
